@@ -30,7 +30,7 @@ This module should be specified as a handler for mapreduce URLs in app.yaml:
 
 # Pipeline has to be imported before webapp.
 try:
-  from mapreduce.third_party import pipeline
+  import pipeline
 except ImportError:
   pipeline = None
 
